@@ -7,4 +7,4 @@
 @ Gitee : https://gitee.com/ZeroSeeker
 """
 from .fastaliyun import *
-import fastoss
+from . import fastoss
